@@ -1,5 +1,5 @@
 
-#define ADTOOL_VERSION "1.3"
+#define ADTOOL_VERSION "1.3.1"
 
 #include <active_directory.h>
 
@@ -53,7 +53,6 @@ void usage() {
 		"attributedelete    <object> <attribute> [value]    delete an attribute or attribute instance\n"
 		"\n"
 		"search             <attribute> <value>             simple ldap search\n"
-		"list               <container>                     list entries in directory\n"
 		"\n",
 		system_config_file);
 }
